function result = process_single_cond(subj,cond,data,conditions, plot_ok)

if nargin < 5
    plot_ok = 0;
end

% condition vectors
discon = [0 0 0 0 0 0 10 20 40 60 80 10 20 40 60 80];
Fcon = [10 15 20 25 30 40 10 10 10 10 10 20 20 20 20 20];

% Set sample freq
if subj< 15 % First 15 subjects 50 Hz, rest 100 Hz
    fs = 50;
else
    fs= 100;
end

% eliminate missing or faultive trials
if subj==2 && ismember(cond,6:16)
    result = [];
    disp(['Subject ' num2str(subj) ', condition ' conditions{cond}]);
    disp('Not processing subject 2, conditions 6-16');
    return;
% elseif subj==3 && cond==12 % eliminate s3c12 because spring stiffness changed and measurement point 20 - 10 was not met
%     result = [];
%     disp(['Subject ' num2str(subj) ', condition ' conditions{cond}]);
%     disp('Not processing subject 3, conditions 12 (20-10)');
%     return;
end

% set variables
Fr = data(:,3);         % reference force vector
FR = max(data(:,3));    % reference force level
Fa = data(:,4);         % force arm sensor
Fb = data(:,2);         % force back sensor
displ = data(:,5);       % displacement sensor
time = (1:length(Fa))/fs; % time
FerrorStart = 0.8*FR;
FerrorEnd   = 0.5*FR;

% Find begin and end of block
b           = find(diff(Fr)>0);
b           = b+1;
% % % length(b)
e           = find(diff(Fr)<0);
if length(b)>length(e)
    b = b(1:end-1);
end

if rem(length(b),2) ~= 0 % Odd number of blocks
    disp(['Odd number of blocks in subject ' num2str(subj) ' condition ' conditions{cond} ', discarding last block']);
    b = b(1:end-1);
    e = e(1:end-1);
end

Nblocks     = length(b);
bV          = b(1:2:Nblocks-1);
bB          = b(2:2:Nblocks);
eV          = e(1:2:Nblocks-1);
eB          = e(2:2:Nblocks);
Nsamples    = e(1)-b(1)+1;

% % % figure
% % % plot(Fr);
% % % hold on 
% % % plot(Fa);
% % % plot(b,Fr(b),'ro');
% % % plot(e,Fr(e),'go');

FaV         = nan(Nsamples,Nblocks/2);
FaB         = nan(Nsamples,Nblocks/2);
FbV         = nan(Nsamples,Nblocks/2);
FbB         = nan(Nsamples,Nblocks/2);

% Determine individual blocks
for blok = 1:Nblocks/2
    FaV(:,blok) = Fa(bV(blok):eV(blok));
    FaB(:,blok) = Fa(bB(blok):eB(blok));
    FbV(:,blok) = Fb(bV(blok):eV(blok));
    FbB(:,blok) = Fb(bB(blok):eB(blok));
end


% % % figure
% % % plot(Fa);
% % % hold on 
% % % for blok=1:Nblocks/2
% % %     plot(bV(blok):eV(blok),Fa(bV(blok):eV(blok)),'r');
% % %     plot(bB(blok):eB(blok),Fa(bB(blok):eB(blok)),'g');
% % %     pause(0.5);
% % % end


% Determine and discard bad trials
exV =[];
exB =[];

ind = 1:0.02*fs;
ind2 = 2.5*fs+1:5*fs;
for blok = 1:Nblocks/2
    % Determine if force is above reference force for the first half second
    if (max(FaV(ind,blok)) > FerrorStart)
        % Reject blok
        exV = [exV blok]; %#ok<AGROW>
    end
    % Determine if force is below second threshold at end of trial
    if (min(FaV(ind2,blok)) < FerrorEnd)
        % Reject blok
        exV = [exV blok]; %#ok<AGROW>
    end
    % Determine if force is above reference force for the first half second
    if (max(FaB(ind,blok)) > FerrorStart)
        % Reject blok
        exB = [exB blok]; %#ok<AGROW>
    end
    % Determine if force is below second threshold at end of trial
    if (min(FaB(ind2,blok)) < FerrorEnd)
        % Reject blok
        exB = [exB blok]; %#ok<AGROW>
    end
end

ex = union(exV,exB);
ex = union(1,ex); % gooi het eerste blok weg als dat niet al gebeurd was
ex = ex(:)';

% Discard bad blocks
FaV(:,ex) = [];
FaB(:,ex) = [];
FbV(:,ex) = [];
FbB(:,ex) = [];

% plot
% % % num2str(subj)
% % % conditions{cond}
% % % num2str(ex);
if (~isempty(ex) && plot_ok == 1)
    titlestr = ['Subj ' num2str(subj) ' Cond ' conditions{cond} ' Bad blocks: ' num2str(ex)];
    figure
    plot(Fr);
    hold on 
    plot(Fa);
    plot(b,Fr(b),'ro');
    plot(e,Fr(e),'go');
    for badV = exV
        ind_tmp = bV(badV):eV(badV);
        plot(ind_tmp,Fa(ind_tmp),'r');
    end
    for badB = exB
        ind_tmp = bB(badB):eB(badB);
        plot(ind_tmp,Fa(ind_tmp),'r');
    end
    title(titlestr);
end

% Determine resuls (mean and std)
FaVm = mean(FaV(ind2,:),1);
FaBm = mean(FaB(ind2,:),1);
FaVs = std(FaV(ind2,:),[],1);
FaBs = std(FaB(ind2,:),[],1);

FbVm = mean(FbV(ind2,:),1);
FbBm = mean(FbB(ind2,:),1);
FbVs = std(FbV(ind2,:),[],1);
FbBs = std(FbB(ind2,:),[],1);

result = [FaVm ; FaVs ; FaBm ; FaBs; FbVm ; FbVs ; FbBm ; FbBs];  

%% plots
fontS =10; % front size of text
fontS2 = 24;

if plot_ok == 2
    figure
    hold on 
    plot(Fr);
    plot(Fa);
    plot(Fb);
    % tmpMV = [];
    % tmpSV = [];
    % tmpMB = [];
    % tmpSB = [];
    titlestr = ['Subj ' num2str(subj) ', cond: ' num2str(cond) ', force-displacement: ' conditions{cond}];
    for blok=1:Nblocks/2
        indV = bV(blok):eV(blok);
        indB = bB(blok):eB(blok);
        indV = indV(ind2);
        indB = indB(ind2);
        plot(indV,Fb(indV),'r');
        plot(indB,Fb(indB),'g');
    %     tmpMV = [tmpMV mean(Fa(indV),1)];
    %     tmpSV = [tmpSV std(Fa(indV),[],1)];
    %     tmpMB = [tmpMB mean(Fa(indB),1)];
    %     tmpSB = [tmpSB std(Fa(indB),[],1)];
    end
    title(titlestr);
    legend('Fr', 'Fa','Fb', 'visual', 'blind')
end

% plot raw data to find typical trial figure for paper
if plot_ok == 3
    figure
    hold on 
    plot(time, Fr, ':k', 'LineWidth', 3);
    plot(time, displ, '--m', 'LineWidth', 3);
    plot(time, Fa, '-.r', 'LineWidth', 3);
    plot(time, Fb, 'b', 'LineWidth', 3);
    
    titlestr = ['Subject ' num2str(subj)  ' condition: ' num2str(Fcon(cond)), ' N - ', num2str(discon(cond)), ' mm' ];
    for blok=1:Nblocks/2
        indV = bV(blok):eV(blok);
        indB = bB(blok):eB(blok);
        indV = indV(ind2);
        indB = indB(ind2);
        plot(time(indV),Fb(indV),'g', 'LineWidth', 4);
        plot(time(indB),Fb(indB),'g', 'LineWidth', 4);
        t1 = text((time(indV(1))-1),1,['V' num2str(blok)]);
        t2 = text((time(indB(1))-1),1,['B' num2str(blok)]);
        t1.FontSize = fontS2;
        t2.FontSize = fontS2;
        set(gca,'FontSize',fontS)
        ylim([-.5 2*FR])
        xlim([0 29.5])
        l= legend('Reference Force','Displacement sensor', 'Force Arm Sensor', 'Force Back Sensor', 'Analysed Data');
        set(l, 'FontSize',fontS);
        ylabel({'Force [N]','Displacement [mm]'},'FontSize',fontS2)
        xlabel('Time [s]', 'FontSize',fontS2)
    end
    title(titlestr);
end

% plot force reproduction error mean(FbBm)-mean(FbVm)
if plot_ok == 4
    f=figure;
    titlestr = ['Subject ' num2str(subj)  ' condition: ' num2str(Fcon(cond)), ' N - ', num2str(discon(cond)), ' mm' ];
    for blok=1:Nblocks/2
        indV = bV(blok):eV(blok);
        indB = bB(blok):eB(blok);
        indV = indV(ind2);
        indB = indB(ind2);
%         plot(time(indV),mean(Fb(indV))-mean(Fa(indV)), 'g')
        hold on 
        plot(time, Fr, ':k');
        plot(time(indV),Fa(indV), 'b')
        plot(time(indV),Fb(indV), 'r')
        plot(time(indV),Fb(indV)-Fa(indV), 'g')
        plot(time(indB),Fb(indB)-Fa(indB), 'c')
%         plot(time(indB),Fa(indB), 'b')
%         plot(time(indB),Fb(indB), 'r')
%         t1 = text((time(indV(1))-1),FR+.5,['V' num2str(blok)]);
%         t2 = text((time(indB(1))-1),FR+.5,['B' num2str(blok)]);
%         t1.FontSize = fontS;
%         t2.FontSize = fontS;
        set(gca,'FontSize',fontS)
        line([0 200],[0 0], 'Color','k', 'LineStyle','-.')
        xlim([0 time(end)])
        
        grid on
        ylim([-10 10])
        
%         legend('reference force','arm sensor','back sensor', 'visual: Fback-Farm', 'blind: Fback-Farm')
        xlabel('time [s]')
        ylabel('Force [N]')
    end
    title(titlestr);
%     saveas(f, ['D:\monahichert\My Documents\MATLAB\forces and displacement\Alistair\figures\raw data - typical subject\Fback-Farm\S',num2str(subj) 'cond' conditions{cond} ,'.fig'])
%     saveas(f, ['D:\monahichert\My Documents\MATLAB\forces and displacement\Alistair\figures\raw data - typical subject\Fback-Farm\S',num2str(subj) 'cond' conditions{cond} ,'.jpg'])
    
end
