%% Description
% This file loads and processes the .csv files for the NASA-TLX software
% found on www.nasatlx.com. 

clc
close all
clear all


%% Multi subject NASA-TLX processing

StartRow = 2;                                         % First row to load from .csv, normal is 2
endRow = 41;                                          % Last row to be loaded, dependent on number of repetitions
WeightRow = [1];                                      % Vector of were the pair-wise comparisons are done.
Npp = 25;                                      % Maximal number of subjects
Nconds = 16;

for subject_tel = 1:Npp
    subject_tel;
        
        filename = ['D:\monahichert\My Documents\Research\Papers\#2 - METC\PlosONE\Data klaar\Uploaded data\NasaTLX\s' num2str(subject_tel) '.csv'];

        % Load data
        [expID,parID,tlxScore,s_mental,s_physical,s_temporal,s_perform,s_effort,s_frustration,w_mental,w_physical,w_temporal,w_perform,w_effort,w_frustration,wW_mental,wW_physical,wW_temporal,wW_perform,wW_effort,wW_frustration] = loadtlx_METCexperiments(filename,StartRow,endRow);
        if subject_tel==2 || subject_tel==11 
        %     result = [];
            disp(['Not processing subject ', num2str(subject_tel)]);
            s_mental = NaN(Nconds, 1);
            s_physical = NaN(Nconds, 1);
            s_temporal = NaN(Nconds, 1);
            s_perform = NaN(Nconds, 1);
            s_effort = NaN(Nconds, 1);
            s_frustration = NaN(Nconds, 1);
%             wW_frustration = NaN(Nconds, 1);
        end
        
        store_mental(:, subject_tel) = s_mental;        
        store_physical(:, subject_tel) = s_physical;
        store_temporal(:, subject_tel) = s_temporal;
        store_perform(:, subject_tel) = s_perform;
        store_effort(:, subject_tel) = s_effort;
        store_frustration(:, subject_tel) = s_frustration;
        
pre=1;
post=16; 
        if subject_tel == 2 || subject_tel==11 
            WeightedTlxScorePre(subject_tel, :)  = nan;
            WeightedTlxScorePost(subject_tel, :)  = nan;
        else
            WeightedTlxScorePre(subject_tel, :)  = ...
                (s_mental(pre,1)*str2num(cell2mat(w_mental(pre)))) +  ...
                (s_physical(pre,1)*str2num(cell2mat(w_physical(pre)))) + ...
                (s_temporal(pre,1)*str2num(cell2mat(w_temporal(pre)))) + ...
                (s_perform(pre,1)*str2num(cell2mat(w_perform(pre)))) + ...
                (s_effort(pre,1)*str2num(cell2mat(w_effort(pre)))) + ...
                (s_frustration(pre,1)*str2num(cell2mat(w_frustration(pre)))); 

        WeightedTlxScorePost(subject_tel, :)  = ...
                (s_mental(post,1)*str2num(cell2mat(w_mental(post)))) +  ...
                (s_physical(post,1)*str2num(cell2mat(w_physical(post)))) + ...
                (s_temporal(post,1)*str2num(cell2mat(w_temporal(post)))) + ...
                (s_perform(post,1)*str2num(cell2mat(w_perform(post)))) + ...
                (s_effort(post,1)*str2num(cell2mat(w_effort(post)))) + ...
                (s_frustration(post,1)*str2num(cell2mat(w_frustration(post)))); 
        end
        
end

WeightedTlxScorePre-WeightedTlxScorePost;
nanmean(WeightedTlxScorePre);
nanmean(WeightedTlxScorePost);
       

%% plots
x = [1 2];
f=figure;
boxplot([WeightedTlxScorePre,WeightedTlxScorePost])
title('Weighted Score Pre vs Post')
set(gca,'XTick',x,'XTickLabel',{'pre', 'post'})
saveas(f, ['D:\monahichert\My Documents\Research\Papers\#2 - METC\PlosONE\Data klaar\Uploaded data\NasaTLX\figures\Weighted Score.fig'])
saveas(f, ['D:\monahichert\My Documents\Research\Papers\#2 - METC\PlosONE\Data klaar\Uploaded data\NasaTLX\figures\Weighted Score.jpg'])

% f=figure;
% plot(x, transpose([WeightedTlxScorePre,WeightedTlxScorePost]), ':')
% title('Weighted Score Pre vs Post')
% set(gca,'XTick',x,'XTickLabel',{'pre', 'post'})


f=figure;
boxplot(transpose(store_mental))
title('Mental')
saveas(f, ['D:\monahichert\My Documents\Research\Papers\#2 - METC\PlosONE\Data klaar\Uploaded data\NasaTLX\figures\Mental.fig'])
saveas(f, ['D:\monahichert\My Documents\Research\Papers\#2 - METC\PlosONE\Data klaar\Uploaded data\NasaTLX\figures\Mental.jpg'])

f=figure;
boxplot(transpose(store_physical))
title('Physical')
saveas(f, ['D:\monahichert\My Documents\Research\Papers\#2 - METC\PlosONE\Data klaar\Uploaded data\NasaTLX\figures\Physical.fig'])
saveas(f, ['D:\monahichert\My Documents\Research\Papers\#2 - METC\PlosONE\Data klaar\Uploaded data\NasaTLX\figures\Physical.jpg'])

f=figure;
boxplot(transpose(store_temporal))
title('Temporal')
saveas(f, ['D:\monahichert\My Documents\Research\Papers\#2 - METC\PlosONE\Data klaar\Uploaded data\NasaTLX\figures\Temporal.fig'])
saveas(f, ['D:\monahichert\My Documents\Research\Papers\#2 - METC\PlosONE\Data klaar\Uploaded data\NasaTLX\figures\Temporal.jpg'])

f=figure;
boxplot(transpose(store_perform))
title('Performance')
saveas(f, ['D:\monahichert\My Documents\Research\Papers\#2 - METC\PlosONE\Data klaar\Uploaded data\NasaTLX\figures\Performance.fig'])
saveas(f, ['D:\monahichert\My Documents\Research\Papers\#2 - METC\PlosONE\Data klaar\Uploaded data\NasaTLX\figures\Performance.jpg'])

f=figure;
boxplot(transpose(store_effort))
title('Effort')
saveas(f, ['D:\monahichert\My Documents\Research\Papers\#2 - METC\PlosONE\Data klaar\Uploaded data\NasaTLX\figures\Effort.fig'])
saveas(f, ['D:\monahichert\My Documents\Research\Papers\#2 - METC\PlosONE\Data klaar\Uploaded data\NasaTLX\figures\Effort.jpg'])

f=figure;
boxplot(transpose(store_frustration))
title('Frustration')
saveas(f, ['D:\monahichert\My Documents\Research\Papers\#2 - METC\PlosONE\Data klaar\Uploaded data\NasaTLX\figures\Frustration.fig'])
saveas(f, ['D:\monahichert\My Documents\Research\Papers\#2 - METC\PlosONE\Data klaar\Uploaded data\NasaTLX\figures\Frustration.jpg'])

